@@ -32,3 +32,17 @@ class CodeStrictField(CharField, Field):
         del kwargs['default']
         return name, path, args, kwargs
 
+class ColorField(CharField, Field):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('max_length', 10)
+        kwargs.setdefault('db_index', True)
+        kwargs.setdefault('default', None)
+        super().__init__(*args, **kwargs)
+
+    def deconstruct(self):
+        name, path, args, kwargs = super().deconstruct()
+        del kwargs["max_length"]
+        del kwargs["db_index"]
+        del kwargs['default']
+        return name, path, args, kwargs
+
