@@ -20,6 +20,7 @@ class Jasper_reportsManager(BaseRefManager):
             'id': record.id,
             'code': record.code,
             'name': record.name,
+            'path': record.path,
             'description': record.description,
             'username': record.username,
             'password': record.password,
@@ -34,16 +35,16 @@ class Jasper_reportsManager(BaseRefManager):
 
 
 class Jasper_reports(BaseRefHierarcy):
-    url = CodeStrictField()
-    username = CodeStrictField()
-    password = CodeStrictField()
+    path = CodeStrictField(default='/jasperserver/rest_v2/reports/')
+    username = CodeStrictField(default='printer')
+    password = CodeStrictField(default='printer')
     host = CodeStrictField()
     port = PositiveIntegerField()
 
     objects = Jasper_reportsManager()
 
     def __str__(self):
-        return f"ID:{self.id}, code: {self.code}, name: {self.name}, description: {self.description}"
+        return f"ID:{self.id}, code: {self.code}, name: {self.name}, path: {self.path}, description: {self.description}"
 
     class Meta:
         verbose_name = 'Отчеты'
